@@ -153,7 +153,7 @@ Note that eopsin errors may be overly restrictive as they aim to prevent code wi
     # apply parameters from the command line to the contract (instantiates parameterized contract!)
     code = code.term
     # UPLC lambdas may only take one argument at a time, so we evaluate by repeatedly applying
-    for d in map(data_from_json, map(json.loads, reversed(args.args))):
+    for d in map(data_from_json, map(json.loads, args.args)):
         code = uplc.ast.Apply(code, d)
     code = uplc.ast.Program("1.0.0", code)
 
